@@ -1,5 +1,7 @@
 package WebXslate;
 
+use strictures;
+
 use Yeb;
 
 BEGIN {
@@ -25,8 +27,13 @@ r "/test" => sub {
 };
 
 r "/json" => sub {
-  ex key => 'value';
-  json { other_key => 'value' };
+	ex key => 'value';
+	json { other_key => 'value' };
+};
+
+r "/other/..." => sub {
+	ex other_app => 'other';
+	chain '+OtherWebTest';
 };
 
 1;
\ No newline at end of file
